@@ -65,7 +65,7 @@ class BDBAApi:
                                          verify=not self.hub.config['insecure'], timeout=600)
                 if not response.ok:
                     if response.status_code == 402:
-                        logging.error("BDBA is not licensed for use with the current Hub instance -- will not be used.")
+                        logging.error("BDBA is not licensed for use with the current Black Duck instance -- will not be used.")
                     else:
                         logging.error(
                             "Problem uploading the file to BDBA -- (Response({}): {})".format(response.status_code,
@@ -90,4 +90,7 @@ class BDBAApi:
                 self.upload_binary_part(project_name, version_name, upd_codelocation_name, binary_file, file_chunk)
 
     def __call__(self, project_name, version_name, codelocation_name, binary_file):
-        self.upload_binary(project_name, version_name, codelocation_name, binary_file)
+        try:
+            self.upload_binary(project_name, version_name, codelocation_name, binary_file)
+        except MemoryError as e:
+            logging.error("Please verify if you are using right version of python - 32bit vs 64bit - {}".format(e))
