@@ -72,7 +72,9 @@ class RunBuildCapture(object):
         self.offline_mode = self.my_args.args.offline
         self.scan_cli_dir = self.my_args.args.scan_cli_dir if self.my_args.args.scan_cli_dir is not None else self.blackduck_output_dir
         self.cov_configure_args = my_args.args.cov_configure_args
-        self.run_modes = list(map(lambda mode: mode.lower(), map(str.strip, self.my_args.args.modes.split(","))))
+        self.run_modes = list(map(lambda mode: mode.lower(), map(lambda s: re.sub("[\"\']", "", s),
+                                                                 map(str.strip, self.my_args.args.modes.split(",")))))
+        logging.debug("run modes is {}".format(self.run_modes))
         self.PKG_MGR_MODE = 'pkg_mgr'
         self.SIG_MODE = 'sig'
         self.BDBA_MODE = 'bdba'
@@ -157,7 +159,7 @@ class RunBuildCapture(object):
                 if not error_matches:
                     phase_dict[p] = 'SUCCESS'
                 if error_matches:
-                    phase_dict[p] = 'ERROR - SEE LOGS FOR DETAILS'.format('\n'.join(error_matches))
+                    phase_dict[p] = 'ERROR - SEE LOGS AT {} FOR DETAILS'.format(self.log_path)
         return phase_dict
 
     @staticmethod
@@ -194,7 +196,7 @@ class RunBuildCapture(object):
             return 'UNKNOWN'
 
     def set_coverity_root(self):
-        self.log_phase("get coverity root information")
+        self.log_phase("Get coverity root information")
         if self.my_args.args.coverity_root and os.path.exists(self.my_args.args.coverity_root):
             logging.debug("Using coverity package given by user")
             cov_home = self.my_args.args.coverity_root
@@ -251,21 +253,11 @@ class RunBuildCapture(object):
             conf_key = " \n "
 
         conf_cmd = util.conf_cmd("--clang", self.cov_bin, cov_conf)
-        conf_cmd += conf_key + util.conf_cmd("--gcc", self.cov_bin, cov_conf)
         conf_cmd += conf_key + util.conf_cmd("--msvc", self.cov_bin, cov_conf)
+
         conf_cmd += conf_key + util.conf_cmd("--template --compiler cc --comptype gcc", self.cov_bin, cov_conf)
-
-        conf_cmd += conf_key + util.conf_cmd("--template --compiler gcc --comptype gcc", self.cov_bin, cov_conf)
         conf_cmd += conf_key + util.conf_cmd("--template --compiler *gcc* --comptype gcc", self.cov_bin, cov_conf)
-
         conf_cmd += conf_key + util.conf_cmd("--template --compiler *c++* --comptype gcc", self.cov_bin, cov_conf)
-        conf_cmd += conf_key + util.conf_cmd("--template --compiler *g++* --comptype gcc", self.cov_bin, cov_conf)
-
-        conf_cmd += conf_key + util.conf_cmd("--template --compiler *g++* --comptype g++", self.cov_bin, cov_conf)
-
-        conf_cmd += conf_key + util.conf_cmd("--template --compiler ld --comptype gcc", self.cov_bin, cov_conf)
-        conf_cmd += conf_key + util.conf_cmd("--template --compiler *-ld --comptype gcc", self.cov_bin, cov_conf)
-        conf_cmd += conf_key + util.conf_cmd("--template --compiler ^ld-* --comptype gcc", self.cov_bin, cov_conf)
 
         conf_cmd += conf_key + util.conf_cmd("--template --compiler ld --comptype ld", self.cov_bin, cov_conf)
         conf_cmd += conf_key + util.conf_cmd("--template --compiler *-ld --comptype ld", self.cov_bin, cov_conf)
@@ -282,11 +274,11 @@ class RunBuildCapture(object):
             cov_add_cmd = ''
 
         if os.path.exists(cov_emit_link_path):
-            self.bld_cmd = '"{}" --emit-link-units -c "{}" --dir "{}"{} "{}"'.format(cov_build_path,
+            self.bld_cmd = '"{}" --emit-link-units -c "{}" --dir "{}" --record-with-source{} "{}"'.format(cov_build_path,
                                                                                      os.path.join(cov_conf, "bld.xml"),
                                                                                      self.cov_dir, cov_add_cmd, sh_path)
         else:
-            self.bld_cmd = '"{}" -c "{}" --dir "{}"{} "{}"'.format(cov_build_path, os.path.join(cov_conf, "bld.xml"),
+            self.bld_cmd = '"{}" -c "{}" --dir "{}" --record-with-source{} "{}"'.format(cov_build_path, os.path.join(cov_conf, "bld.xml"),
                                                                    self.cov_dir, cov_add_cmd, sh_path)
 
         full_cmd = conf_cmd + conf_key + self.bld_cmd
