@@ -48,6 +48,7 @@ class SigScanner:
         self.os_dist = os_dist
         self.api_token = hub_api.api_token
         self.cov_base_path = cov_base_path
+        self.blackduck_output_dir = blackduck_output_dir
         self.sig_scan_output_directory = os.path.join(blackduck_output_dir, 'sig_scan')
         self.sig_files_output_path = os.path.join(self.sig_scan_output_directory, 'sig_files')
         self.sig_scan_tar_output_directory = os.path.join(self.sig_scan_output_directory, 'tar_file')
@@ -61,7 +62,9 @@ class SigScanner:
         self.sig_scanner_found = False
         self.json_file = self.bdio_file = None
         self.upload_dry_run = self.use_offline_files
+        self.proxy_settings = ''
         self.url_split = "://"
+        self.op_sys = platform.system()
 
     def get_files_to_tar(self):
         """ collect all files to send to signature scanner"""
@@ -91,8 +94,14 @@ class SigScanner:
             shutil.rmtree(self.sig_files_output_path)
         files_count = 0
         for each_file in tqdm.tqdm(self.files_to_tar, total=len(self.files_to_tar)):
+            dest_filepath = ''
             try:
-                dest_filepath = self.sig_files_output_path + each_file
+                # exclude coverity configuration header files that are in the emit directory
+                if os.path.join(self.blackduck_output_dir, 'emit') in each_file:
+                    continue
+                # split drive -> drive is mount point and path is in tail
+                file_spath = os.path.splitdrive(each_file)[1]
+                dest_filepath = self.sig_files_output_path + file_spath
                 dest_folder = os.path.dirname(dest_filepath)
 
                 if not os.path.exists(dest_folder):
@@ -101,8 +110,14 @@ class SigScanner:
                 files_count += 1
             except IsADirectoryError:
                 continue
+            except PermissionError:
+                continue
             except Exception as e:
-                logging.error("error is {}".format(e))
+                if len(dest_filepath) > 260 and self.op_sys == 'Windows':
+                    logging.warning("You are using Windows and the file path exceeds the default limit of 260 characters. Check the character limit on your system and consider removing the limit to include this file in the scan. The rest of the scan will proceed.")
+                    logging.warning("Not copying file to location: {}".format(dest_filepath))
+                else:
+                    logging.error("Exception is {}".format(e))
                 continue
         logging.debug("Number of files added in sig_files directory are {}".format(files_count))
 
@@ -125,11 +140,10 @@ class SigScanner:
         """
         construct the URL from which to download the signature scanner from Black Duck
         """
-        op_sys = platform.system()
         sig_scanner_url = self.hub_api.hub.config['baseurl'] + '/download/scan.cli'
-        if op_sys == 'Windows':
+        if self.op_sys == 'Windows':
             sig_scanner_url += '-windows'
-        if op_sys == 'Darwin':
+        if self.op_sys == 'Darwin':
             sig_scanner_url += '-macosx'
         sig_scanner_url += '.zip'
         return sig_scanner_url
@@ -270,9 +284,10 @@ class SigScanner:
         Construct the signature scanner command to run
         """
         java_path, standalone_jar_path = self.get_java_and_standalone_jar_paths()
-        sig_scanner_command = '"{}" -Done-jar.silent=true -Done-jar.jar.path="{}" -Xmx4096m -jar "{}" --no-prompt -v --project "{}" --release "{}" --name "{}" --individualFileMatching=ALL --binaryAllowedList h,hpp,cpp,c '.format(
+        sig_scanner_command = '"{}" -Done-jar.silent=true -Done-jar.jar.path="{}"{} -Xmx4096m -jar "{}" --no-prompt -v --project "{}" --release "{}" --name "{}" --individualFileMatching=ALL --binaryAllowedList h,hpp,cpp,c '.format(
             java_path,
             os.path.join(self.scan_cli_path, 'lib', 'cache', 'scan.cli.impl-standalone.jar'),
+            self.proxy_settings,
             standalone_jar_path,
             self.project_name, self.project_version_name,
             self.code_location_name)
@@ -293,7 +308,8 @@ class SigScanner:
         if self.additional_sig_scan_args:
             sig_scanner_command += '{} '.format(self.parse_additional_args())
 
-        output_dir = self.sig_files_output_path if self.expand_sig_files else (self.sig_scan_tar_output_directory)
+        output_dir = '"{}"'.format(
+            self.sig_files_output_path if self.expand_sig_files else (self.sig_scan_tar_output_directory))
         sig_scanner_command += output_dir
 
         logging.info("sig scanner command is {}".format(sig_scanner_command))
@@ -337,6 +353,9 @@ class SigScanner:
             shutil.rmtree(os.path.join(self.sig_scan_output_directory, 'data'))  # remove data directory if exists
         env = dict(os.environ)
         env['BD_HUB_TOKEN'] = self.api_token
+        scan_cli_opts = os.getenv('SCAN_CLI_OPTS', '')
+        if scan_cli_opts != '':
+            self.proxy_settings = " {}".format(scan_cli_opts)
         sig_scanner_command = self.build_sig_scanner_command()
         util.run_cmd(sig_scanner_command, env=env, curdir=self.sig_scan_output_directory)
         logging.info("Finished running the signature scanner")
