@@ -47,28 +47,28 @@ class C_Parser:
         self.parser.add_argument('-d', '--build_dir',
                                  required=True,
                                  type=C_Parser.required_dir_exists,
-                                 help='Directory from which to run build')
+                                 help='Directory from which to run build. Absolute path (not relative) information is required')
 
         self.parser.add_argument('-Cov', '--coverity_root',
                                  metavar='coverity_root',
                                  dest='coverity_root',
                                  default='',
                                  type=str,
-                                 help='Base directory for coverity.If not specified, blackduck-c-cpp downloads latest mini coverity package from GCP for authorized Black Duck customers for Black Duck versions >= 2021.10')
+                                 help='Base directory for coverity.If not specified, blackduck-c-cpp downloads latest mini coverity package from GCP for authorized Black Duck customers for Black Duck versions >= 2021.10. Absolute path (not relative) information is required')
 
         self.parser.add_argument('-Cd', '--cov_output_dir',
                                  metavar='cov_output_dir',
                                  dest='cov_output_dir',
                                  default='',
                                  type=str,
-                                 help='Target directory for coverity output files.If not specified, defaults to user_home/.synopsys/blackduck-c-cpp/output/project_name')
+                                 help='Target directory for coverity output files.If not specified, defaults to user_home/.synopsys/blackduck-c-cpp/output/project_name. Absolute path (not relative) information is required')
 
         self.parser.add_argument('-od', '--output_dir',
                                  metavar='output_dir',
                                  dest='output_dir',
                                  default='',
                                  type=str,
-                                 help='Target directory for blackduck-c-cpp output files.If not specified, defaults to user_home/.synopsys/blackduck-c-cpp/output/project_name')
+                                 help='Target directory for blackduck-c-cpp output files.If not specified, defaults to user_home/.synopsys/blackduck-c-cpp/output/project_name. Absolute path (not relative) information is required')
 
         self.parser.add_argument('-s', '--skip_build',
                                  type=C_Parser.str2bool,
@@ -167,7 +167,7 @@ class C_Parser:
                                  nargs='?',
                                  const=True,
                                  default=False,
-                                 help='Debug mode selection')
+                                 help='Debug mode selection. Setting debug: True sends all the files we found to all matching types. By default, it will only send files not detected by package manager to BDBA and Signature matching.')
 
         self.parser.add_argument('-st', '--skip_transitives',
                                  type=C_Parser.str2bool,
@@ -216,7 +216,7 @@ class C_Parser:
                                  dest='scan_cli_dir',
                                  default=None,
                                  type=str,
-                                 help='scan cli directory')
+                                 help='scan cli directory. Absolute path (not relative) information is required')
 
         self.parser.add_argument('-Cc', '--cov_configure_args',
                                  metavar='cov_configure_args',
