@@ -26,7 +26,8 @@ def conf_cmd(spec, cov_bin, cov_conf):
 def run_cmd(cmd, curdir=None, suppress_output=False, env=None):
     logging.debug("command to run in run_cmd {}".format(cmd))
     if env and curdir:
-        process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, env=env, shell=True, cwd=curdir)
+        process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, env=env, shell=True,
+                                   cwd=curdir)
     elif env:
         process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, env=env, shell=True)
     elif curdir:
@@ -45,9 +46,13 @@ def run_cmd(cmd, curdir=None, suppress_output=False, env=None):
                     if suppress_output:
                         logging.debug(realtime_output.strip())
                 except UnicodeEncodeError:
-                    pass
+                    logging.warning("UnicodeEncodeError Exception occurred: skipping a line")
+                except UnicodeDecodeError:
+                    logging.warning("UnicodeDecodeError Exception occurred: skipping a line")
         except UnicodeEncodeError:
-            pass
+            logging.warning("UnicodeEncodeError Exception occurred: skipping a line")
+        except UnicodeDecodeError:
+            logging.warning("UnicodeDecodeError Exception occurred: skipping a line")
     return process.returncode
 
 
